@@ -24,6 +24,7 @@ generate_keybindings! {
   submit,
   refresh,
   toggle_theme,
+  cycle_main_views,
   jump_to_current_context,
   jump_to_all_context,
   jump_to_utilization,
@@ -123,6 +124,12 @@ pub const DEFAULT_KEYBINDING: KeyBindings = KeyBindings {
     desc: "Switch to resource utilization view",
     context: HContext::General,
   },
+  cycle_main_views: KeyBinding {
+    key: Key::Tab,
+    alt: None,
+    desc: "Cycle through main views",
+    context: HContext::General,
+  },
   copy_to_clipboard: KeyBinding {
     key: Key::Char('c'),
     alt: None,
